@@ -23,8 +23,9 @@ class OmniousColorEnum(enum.Enum):
     silver = 20
     rosegold = 21
 
-    def get_omnious_color_enum(self, key):
-        if key is None:
-            return 0
-        else:
-            return OmniousColorEnum[key.replace('/', '').replace('-', '')].value
\ No newline at end of file
+
+def get_omnious_color_enum(key):
+    if key is None:
+        return 0
+    else:
+        return OmniousColorEnum[key.replace('/', '').replace('-', '')].value
\ No newline at end of file
